@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from typing import Dict
+from convexus.icontoolkit.BigInt import BigInt
 
 @dataclass
 class Slot0:
@@ -18,7 +19,7 @@ class Slot0:
       int(data['observationCardinality'], 0),
       int(data['observationCardinalityNext'], 0),
       int(data['observationIndex'], 0),
-      int(data['sqrtPriceX96'], 0),
+      BigInt(data['sqrtPriceX96']),
       int(data['tick'], 0),
       bool(int(data['unlocked'], 0))
     )
