@@ -3,8 +3,6 @@ from convexus.sdkcore.constants import Rounding
 from convexus.sdkcore.entities.currency import Currency
 from convexus.sdkcore.entities.fractions.fraction import Fraction
 from convexus.sdkcore.entities.fractions.currencyAmount import CurrencyAmount
-from convexus.sdk.internalConstants import Q192
-from convexus.sdk.utils.tickMath import TickMath
 
 class Price(Fraction):
   def __init__(self, baseCurrency: Currency, quoteCurrency: Currency, denominator: BigintIsh, numerator: BigintIsh):
@@ -18,12 +16,7 @@ class Price(Fraction):
 
   @classmethod
   def fromSqrtPrice(cls, baseCurrency: Currency, quoteCurrency: Currency, sqrtPrice: BigintIsh) -> 'Price':
-    return Price(baseCurrency, quoteCurrency, Q192, sqrtPrice**2)
-
-  @classmethod
-  def fromTick(cls, baseCurrency: Currency, quoteCurrency: Currency, tick: int) -> 'Price':
-    sqrtPrice = TickMath.getSqrtRatioAtTick(tick)
-    return cls.fromSqrtPrice(baseCurrency, quoteCurrency, sqrtPrice)
+    return Price(baseCurrency, quoteCurrency, 2**192, sqrtPrice**2)
 
   @classmethod
   def fromAmounts(cls, baseAmount: CurrencyAmount, quoteAmount: CurrencyAmount) -> 'Price':
